NLSL: correl.f90 File Reference

NLSL

- Main Page
- Modules
- Data Types List
- Files

- File List
- File Members

Functions/Subroutines
correl.f90 File Reference

Go to the source code of this file.

## Functions/Subroutines
subroutine | correl (data, spctr, npt, ans, fft)

## Function/Subroutine Documentation

subroutine correl | ( | double precision, dimension(npt) | data,
|  | double precision, dimension(npt) | spctr,
|  | integer | npt,
|  | double precision, dimension(2*npt) | ans,
|  | double precision, dimension(2*npt) | fft
| ) |  |

Definition at line 28 of file correl.f90.

Here is the call graph for this function:

Here is the caller graph for this function: